summaryrefslogtreecommitdiffstats
path: root/src/entryview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryview.cpp')
-rw-r--r--src/entryview.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/entryview.cpp b/src/entryview.cpp
index 0539754..3499adc 100644
--- a/src/entryview.cpp
+++ b/src/entryview.cpp
@@ -46,7 +46,7 @@ EntryView::EntryView(TQWidget* parent_, const char* name_) : KHTMLPart(parent_,
setJavaEnabled(false);
setMetaRefreshEnabled(false);
setPluginsEnabled(false);
- clear(); // needed for initial tqlayout
+ clear(); // needed for initial layout
view()->setAcceptDrops(true);
DropHandler* drophandler = new DropHandler(this);
@@ -76,7 +76,7 @@ void EntryView::clear() {
write(m_textToShow);
}
end();
- view()->tqlayout(); // I need this because some of the margins and widths may get messed up
+ view()->layout(); // I need this because some of the margins and widths may get messed up
}
void EntryView::showEntry(Data::EntryPtr entry_) {
@@ -121,7 +121,7 @@ void EntryView::showEntry(Data::EntryPtr entry_) {
// myDebug() << dom.toString() << endl;
#if 0
kdWarning() << "EntryView::showEntry() - turn me off!" << endl;
- TQFile f1(TQString::tqfromLatin1("/tmp/test.xml"));
+ TQFile f1(TQString::fromLatin1("/tmp/test.xml"));
if(f1.open(IO_WriteOnly)) {
TQTextStream t(&f1);
t << dom.toString();
@@ -146,7 +146,7 @@ void EntryView::showEntry(Data::EntryPtr entry_) {
#if 0
kdWarning() << "EntryView::showEntry() - turn me off!" << endl;
- TQFile f2(TQString::tqfromLatin1("/tmp/test.html"));
+ TQFile f2(TQString::fromLatin1("/tmp/test.html"));
if(f2.open(IO_WriteOnly)) {
TQTextStream t(&f2);
t << html;
@@ -158,7 +158,7 @@ void EntryView::showEntry(Data::EntryPtr entry_) {
write(html);
end();
// not need anymore?
- view()->tqlayout(); // I need this because some of the margins and widths may get messed up
+ view()->layout(); // I need this because some of the margins and widths may get messed up
}
void EntryView::showText(const TQString& text_) {
@@ -174,19 +174,19 @@ void EntryView::setXSLTFile(const TQString& file_) {
if(file_.at(0) == '/') {
m_xsltFile = file_;
} else {
- const TQString templateDir = TQString::tqfromLatin1("entry-templates/");
+ const TQString templateDir = TQString::fromLatin1("entry-templates/");
m_xsltFile = locate("appdata", templateDir + file_);
if(m_xsltFile.isEmpty()) {
if(!file_.isEmpty()) {
kdWarning() << "EntryView::setXSLTFile() - can't locate " << file_ << endl;
}
- m_xsltFile = locate("appdata", templateDir + TQString::tqfromLatin1("Fancy.xsl"));
+ m_xsltFile = locate("appdata", templateDir + TQString::fromLatin1("Fancy.xsl"));
if(m_xsltFile.isEmpty()) {
- TQString str = TQString::tqfromLatin1("<qt>");
+ TQString str = TQString::fromLatin1("<qt>");
str += i18n("Tellico is unable to locate the default entry stylesheet.");
str += TQChar(' ');
str += i18n("Please check your installation.");
- str += TQString::tqfromLatin1("</qt>");
+ str += TQString::fromLatin1("</qt>");
KMessageBox::error(view(), str);
clear();
return;
@@ -244,7 +244,7 @@ void EntryView::setXSLTFile(const TQString& file_) {
}
// look for a file that gets installed to know the installation directory
- TQString appdir = KGlobal::dirs()->findResourceDir("appdata", TQString::tqfromLatin1("pics/tellico.png"));
+ TQString appdir = KGlobal::dirs()->findResourceDir("appdata", TQString::fromLatin1("pics/tellico.png"));
m_handler->addStringParam("datadir", TQFile::encodeName(appdir));
// if we don't have to reload the images, then just show the entry and we're done
@@ -260,7 +260,7 @@ void EntryView::setXSLTFile(const TQString& file_) {
void EntryView::slotRefresh() {
setXSLTFile(m_xsltFile);
showEntry(m_entry);
- view()->tqrepaint();
+ view()->repaint();
}
// do some contortions in case the url is relative
@@ -340,10 +340,10 @@ void EntryView::resetColors() {
// this is a rather bad hack to get around the fact that the image cache is not reloaded when
// the gradient files are changed on disk. Setting the URLArgs for write() calls doesn't seem to
- // work. So force a reload with a temp file, then catch the completed signal and tqrepaint
- TQString s = TQString::tqfromLatin1("<html><body><img src=\"%1\"><img src=\"%2\"></body></html>")
- .tqarg(dir + TQString::tqfromLatin1("gradient_bg.png"))
- .tqarg(dir + TQString::tqfromLatin1("gradient_header.png"));
+ // work. So force a reload with a temp file, then catch the completed signal and repaint
+ TQString s = TQString::fromLatin1("<html><body><img src=\"%1\"><img src=\"%2\"></body></html>")
+ .arg(dir + TQString::fromLatin1("gradient_bg.png"))
+ .arg(dir + TQString::fromLatin1("gradient_header.png"));
delete m_tempFile;
m_tempFile = new KTempFile;